pub enum ReadError {
RepositoryRoot {
source: Error,
},
ResolvePath {
path: String,
source: Error,
},
OutsideRepository {
path: String,
},
Open {
path: String,
source: Error,
},
Read {
path: String,
source: Error,
},
OffsetBeyondEnd {
offset: u64,
path: String,
},
LineTooLong {
line: u64,
path: String,
},
InvalidUtf8 {
line: u64,
path: String,
},
ScanLimitExceeded {
limit: usize,
path: String,
},
Encode(Error),
}Expand description
Failure while safely executing one repository-relative read.
Variants
RepositoryRoot
The repository root could not be resolved.
ResolvePath
The requested path could not be resolved.
OutsideRepository
The canonical requested path escapes the canonical repository root.
Open
The requested file could not be opened.
Read
The requested file could not be read.
OffsetBeyondEnd
The requested line does not exist.
LineTooLong
A line cannot fit in the bounded tool result.
Fields
InvalidUtf8
File content is not valid UTF-8 text.
ScanLimitExceeded
The read consumed its bounded file-scan allowance.
Fields
Encode(Error)
The successful result could not be encoded for the model.