pub struct ModelRequest { /* private fields */ }Expand description
Provider-neutral input for one model request.
Implementations
Sourceimpl ModelRequest
impl ModelRequest
Sourcepub fn new(prompt: impl Into<String>, schema: OutputSchema) -> Self
pub fn new(prompt: impl Into<String>, schema: OutputSchema) -> Self
Creates a model request whose response must match schema.
Sourcepub fn with_tool(self, tool: ToolDefinition) -> Self
pub fn with_tool(self, tool: ToolDefinition) -> Self
Advertises one native function tool for this request.
Sourcepub fn schema(&self) -> &OutputSchema
pub fn schema(&self) -> &OutputSchema
Returns the schema that the response must match.
Sourcepub fn tools(&self) -> &[ToolDefinition]
pub fn tools(&self) -> &[ToolDefinition]
Returns the native function tools explicitly advertised by the caller.